# -*- coding:utf-8 -*-
from Products.CMFCore.utils import getToolByName


def uninstall(portal, reinstall=False):

    if not reinstall:
        # normal uninstall
        setup_tool = getToolByName(portal, 'portal_setup')
        profile = 'profile-Products.BrFieldsAndWidgets:uninstall'
        setup_tool.runAllImportStepsFromProfile(profile)

        return "Ran all uninstall steps."



# -*- coding: utf-8 -*-
import unittest2 as unittest

from Products.BrFieldsAndWidgets.testing import INTEGRATION_TESTING

PROJECTNAME = 'Products.BrFieldsAndWidgets'


class TestValidorsRegistration(unittest.TestCase):

    layer = INTEGRATION_TESTING

    def test_cpf_registration(self):
        from Products.validation import validation
        v = validation.validatorFor('isCPF')
        self.failUnlessEqual(v('81057807559'), 1)
        self.failIfEqual(v('8105780755x'), 1)

    def test_cnpj_registration(self):
        from Products.validation import validation
        v = validation.validatorFor('isCNPJ')
        self.failUnlessEqual(v('90.656.353/0001-37'), 1)
        self.failIfEqual(v('90.656.353/0001-36'), 1)

    def test_cep_registration(self):
        from Products.validation import validation
        v = validation.validatorFor('isCEP')
        self.failUnlessEqual(v('05417-010'), 1)
        self.failIfEqual(v('05417'), 1)

    def test_phone_registration(self):
        from Products.validation import validation
        v = validation.validatorFor('isBrPhone')
        self.failUnlessEqual(v('(11)38982121'), 1)
        self.failIfEqual(v('113898-212121'), 1)


class TestCPFValidator(unittest.TestCase):

    layer = INTEGRATION_TESTING

    def setUp(self):
        from Products.validation import validation
        portal = self.layer['portal']
        self.portal = portal
        self.v = validation.validatorFor('isCPF')

    def test_cpf_unformatted(self):
        self.failUnlessEqual(self.v('81057807559'), 1)
        self.failIfEqual(self.v('81057807554'), 1)
        self.failIfEqual(self.v('810578075xx'), 1)

    def test_cpf_formatted(self):
        self.failUnlessEqual(self.v('810.578.075-59'), 1)
        self.failUnlessEqual(self.v('810.578.075/59'), 1)
        self.failIfEqual(self.v('810.578.075-54'), 1)
        self.failIfEqual(self.v('810.578.075/xx'), 1)

    def test_cpf_wrong_size(self):
        self.failIfEqual(self.v('8105780755'), 1)
        self.failIfEqual(self.v('810.5782075/59'), 1)
        self.failIfEqual(self.v('810.578.075-542'), 1)
        self.failIfEqual(self.v('8103578.075399'), 1)


class TestCNPJValidator(unittest.TestCase):

    layer = INTEGRATION_TESTING

    def setUp(self):
        from Products.validation import validation
        portal = self.layer['portal']
        self.portal = portal
        self.v = validation.validatorFor('isCNPJ')

    def test_cnpj_unformatted(self):
        self.failUnlessEqual(self.v('90656353000137'), 1)
        self.failUnlessEqual(self.v('00000000000191'), 1)
        self.failIfEqual(self.v('90656353000134'), 1)
        self.failIfEqual(self.v('10000000000191'), 1)

    def test_cnpj_formatted(self):
        self.failUnlessEqual(self.v('90.656.353/0001-37'), 1)
        self.failUnlessEqual(self.v('00.000.000/0001-91'), 1)
        self.failIfEqual(self.v('90.656.353/0001-34'), 1)
        self.failIfEqual(self.v('10.000.000/0001-91'), 1)

    def test_cnpj_wrong_size(self):
        self.failIfEqual(self.v('9065635300017'), 1)
        self.failIfEqual(self.v('90.656.35300001-37'), 1)
        self.failIfEqual(self.v('000000000000191'), 1)
        self.failIfEqual(self.v('00.000.0000001-911'), 1)
        self.failIfEqual(self.v('90.656.3530/000134'), 1)
        self.failIfEqual(self.v('10.000.000/0001-921'), 1)


class TestCEPValidator(unittest.TestCase):

    layer = INTEGRATION_TESTING

    def setUp(self):
        from Products.validation import validation
        portal = self.layer['portal']
        self.portal = portal
        self.v = validation.validatorFor('isCEP')

    def test_cep_unformatted(self):
        self.failUnlessEqual(self.v('05421001'), 1)
        self.failUnlessEqual(self.v('03087000'), 1)
        self.failIfEqual(self.v('0308700x'), 1)
        self.failIfEqual(self.v('0542100x'), 1)

    def test_cep_formatted(self):
        self.failUnlessEqual(self.v('05421-001'), 1)
        self.failUnlessEqual(self.v('03087-000'), 1)
        self.failIfEqual(self.v('03087-00x'), 1)
        self.failIfEqual(self.v('05421-00x'), 1)


class TestPhoneValidator(unittest.TestCase):

    layer = INTEGRATION_TESTING

    def setUp(self):
        from Products.validation import validation
        portal = self.layer['portal']
        self.portal = portal
        self.v = validation.validatorFor('isBrPhone')

    def test_phone_unformatted(self):
        self.failUnlessEqual(self.v('1138982121'), 1)
        self.failUnlessEqual(self.v('1120953000'), 1)
        self.failUnlessEqual(self.v('08007764832'), 1)
        self.failUnlessEqual(self.v('03007897771'), 1)
        self.failIfEqual(self.v('38982121'), 1)
        self.failIfEqual(self.v('2920953000'), 1)
        self.failIfEqual(self.v('18007764832'), 1)
        self.failIfEqual(self.v('33007897771'), 1)

    def test_phone_formatted(self):
        self.failUnlessEqual(self.v('(11)3898.2121'), 1)
        self.failUnlessEqual(self.v('(11)2095.3000'), 1)
        self.failUnlessEqual(self.v('0800-776-4832'), 1)
        self.failUnlessEqual(self.v('0300-789-7771'), 1)
        self.failIfEqual(self.v('3898-2121'), 1)
        self.failIfEqual(self.v('(29)2095.3000'), 1)
        self.failIfEqual(self.v('1800-776-4832'), 1)
        self.failIfEqual(self.v('3300-789-7771'), 1)

    def test_phone_with_international_codes(self):
        self.failIfEqual(self.v('+55(11)3898.2121'), 1)
        self.failIfEqual(self.v('+55(11)2095.3000'), 1)
        self.failIfEqual(self.v('+550800-776-4832'), 1)
        self.failIfEqual(self.v('+550300-789-7771'), 1)
        self.failIfEqual(self.v('+553898-2121'), 1)
        self.failIfEqual(self.v('+55(29)2095.3000'), 1)
        self.failIfEqual(self.v('+551800-776-4832'), 1)
        self.failIfEqual(self.v('+553300-789-7771'), 1)

    def test_phone_with_letters(self):
        self.failIfEqual(self.v('(11)3333PORTO'), 1)
        self.failIfEqual(self.v('113333PORTO'), 1)
        self.failIfEqual(self.v('11-3333-PORTO'), 1)


def test_suite():
    return unittest.defaultTestLoader.loadTestsFromName(__name__)



# -*- coding: utf-8 -*-

from Products.CMFCore import utils
from Products.CMFCore.DirectoryView import registerDirectory
from Products.Archetypes.public import process_types, listTypes

from Products.BrFieldsAndWidgets.config import ADD_CONTENT_PERMISSION
from Products.BrFieldsAndWidgets.config import GLOBALS
from Products.BrFieldsAndWidgets.config import PROJECTNAME
from Products.BrFieldsAndWidgets.config import SKINS_DIR

registerDirectory(SKINS_DIR, GLOBALS)

from zope.i18nmessageid import MessageFactory as BaseMessageFactory
MessageFactory = BaseMessageFactory('Products.BrFieldsAndWidgets')

from Products.BrFieldsAndWidgets import validators
from Products.BrFieldsAndWidgets.content import BrFieldsAndWidgetsDemo


def initialize(context):

    content_types, constructors, ftis = process_types(
        listTypes(PROJECTNAME),
        PROJECTNAME)
    utils.ContentInit(
            PROJECTNAME + ' Content',
            content_types = content_types,
            permission = ADD_CONTENT_PERMISSION,
            extra_constructors = constructors,
            fti = ftis,
            ).initialize(context)



PROJECTNAME = "BrFieldsAndWidgets"
SKINS_DIR = 'skins'
GLOBALS = globals()

try:
    from Products.CMFCore.permissions import AddPortalContent
except:
    from Products.CMFCore.CMFCorePermissions import AddPortalContent

ADD_CONTENT_PERMISSION = AddPortalContent

try:
    # Plone 4 and higher
    import plone.app.upgrade
    USE_BBB_VALIDATORS = False
except ImportError:
    # BBB Plone 3
    USE_BBB_VALIDATORS = True



# -*- coding: utf-8 -*-
__author__ = '''Simples Consultoria'''
__docformat__ = 'plaintext'

from zope.interface import implements
from zope.component import queryUtility

from Products.validation.interfaces import ivalidator
from zope.schema.interfaces import IVocabularyFactory

from Products.validation.config import validation
from Products.validation.interfaces.IValidator import IValidator

from Products.BrFieldsAndWidgets import MessageFactory as _
from Products.BrFieldsAndWidgets.config import USE_BBB_VALIDATORS

listValidators = []


class ValidadorCPF:
    """
    Validador para verificar se o CPF informado e valido
    Baseado em http://www.pythonbrasil.com.br/moin.cgi/VerificadorDeCPF .
    """

    if USE_BBB_VALIDATORS:
        __implements__ = (ivalidator, )
    else:
        implements(IValidator)

    def __init__(self, name, title='', description=''):
        self.name = name
        self.title = title or name
        self.description = description

    def __call__(self, value, *args, **kw):
        cpf = value
        cpf = ''.join([c for c in value if c.isdigit()])

        if len(cpf) != 11:
            return _(u"CPF precisa ter 11 dígitos.")
        elif len(cpf)==11:
            vtemp = [int(cpf[:1]) for i in list(cpf)]
            cpf2 = [int(i) for i in list(cpf)]
            if cpf2 == vtemp:
                return _(u"CPF inválido.")

            tmp = cpf[:9]
            ltmp = [int(i) for i in list(tmp)]

            while len(ltmp) < 11:
                R = sum(map(lambda(i, v): (len(ltmp)+1-i)*v,
                                         enumerate(ltmp))) % 11

                if R > 1:
                    f = 11 - R
                else:
                    f = 0
                ltmp.append(f)

            if cpf2 != ltmp:
                return _(u"O dígito verificador do CPF não confere.")
        return True


listValidators.append(ValidadorCPF('isCPF',
                                   title=_(u'Validator de CPF'),
                                   description=''))


class ValidadorCNPJ:
    """
    Validador para verificar se o CNPJ informado e valido.
    Baseado em http://www.pythonbrasil.com.br/moin.cgi/VerificadorDeCnpj
    """

    if USE_BBB_VALIDATORS:
        __implements__ = (ivalidator, )
    else:
        implements(IValidator)

    def __init__(self, name, title='', description=''):
        self.name = name
        self.title = title or name
        self.description = description

    def __call__(self, value, *args, **kw):
        digits = [int(c) for c in value if c.isdigit()]
        if len(digits) != 14:
            return _(u"O CNPJ deve ter 14 dígitos.")
        cnpj = digits[:12]
        prod = [5, 4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2]
        while len(cnpj) < 14:
            r = sum([x*y for (x, y) in zip(cnpj, prod)])%11
            if r > 1:
                f = 11 - r
            else:
                f = 0
            cnpj.append(f)
            prod.insert(0, 6)
        return ((cnpj == digits) and True) or \
                _(u"O CNPJ informado é inválido.")


listValidators.append(ValidadorCNPJ('isCNPJ',
                                    title=_(u'Validator de CNPJ'),
                                    description=''))


class ValidadorCEP:
    """
    Validador para informar se o CEP informado is valido. Sao aceitos codigos
    de enderecamento postal em duas formas:Oito digitos consecutivos ou cinco
    digitos, hifen, tres digitos, ou seja, XXXXXXXX ou XXXXX-XXX, onde cada X
    pode ser qualquer digito entre 0 e 9.
    """

    if USE_BBB_VALIDATORS:
        __implements__ = (ivalidator, )
    else:
        implements(IValidator)

    def __init__(self, name, title='', description=''):
        self.name = name
        self.title = title or name
        self.description = description

    def __call__(self, value, *args, **kw):
        cep = ''.join([c for c in value if c.isdigit()])

        if not(len(cep)==8):
            return _(u"O cep informado é inválido.")
        return True

listValidators.append(ValidadorCEP('isCEP',
                                   title=_(u'Validator de CEP'),
                                   description=''))


class ValidadorBrPhone:
    """
    Validador para telefones brasileiros. Suportando os formatos:
        XXXXXXXXXX (1155553211) - Novos telefones
        XXXXXXXXX  (115552133) - Antigos telefones
        0n00XXXXXXX (n sendo 3 ou 8)
        0n00XXXXXX (n sendo 3 ou 8)
    """

    if USE_BBB_VALIDATORS:
        __implements__ = (ivalidator, )
    else:
        implements(IValidator)

    def __init__(self, name, title='', description=''):
        self.name = name
        self.title = title or name
        self.description = description

    def __call__(self, value, *args, **kw):

        if value.startswith('+'):
            return _(u"Telefone inválido")
        phone = ''.join([c for c in value if c.isdigit()])
        len_phone = len(phone)
        status = True
        if phone.startswith('0'):
            if not((self.validate_cng(phone[:4])) and (len_phone in [10, 11])):
                status = False
        elif not((self.validate_ddd(phone[:2])) and (len_phone in [9, 10])):
            status = False

        return status or _(u"Telefone inválido")

    def validate_ddd(self, value):
        util = queryUtility(IVocabularyFactory, 'brasil.ddd')
        ddd = util()
        try:
            item = ddd.by_token[value]
            return item
        except KeyError:
            return False

    def validate_cng(self, value):
        util = queryUtility(IVocabularyFactory, 'brasil.cng')
        cng = util()
        try:
            item = cng.by_token[value]
            return item
        except KeyError:
            return False


listValidators.append(ValidadorBrPhone('isBrPhone',
                                       title=_(u'Validator de Telefone'),
                                       description=''))


for validador in listValidators:
    validation.register(validador)



# -*- coding:utf-8 -*-
""" demonstrates the use of BrFieldsAndWidgets """
from AccessControl import ClassSecurityInfo

from Products.Archetypes import atapi

from Products.BrFieldsAndWidgets.config import PROJECTNAME

from Products.BrFieldsAndWidgets.content.BrFieldsAndWidgets import CPFField
from Products.BrFieldsAndWidgets.content.BrFieldsAndWidgets import CEPField
from Products.BrFieldsAndWidgets.content.BrFieldsAndWidgets import CNPJField
from Products.BrFieldsAndWidgets.content.BrFieldsAndWidgets import BrPhoneField


schema = atapi.BaseSchema + atapi.Schema((
    CPFField('cpf',
                searchable=1,
                ),
    CEPField('cep',
                searchable=1,
                ),
    CNPJField('cnpj',
                searchable=1,
                ),
    BrPhoneField('phone',
                searchable=1,
                ),
))


class BrFieldsAndWidgetsDemo(atapi.BaseContent):
    """
    Demo for BrFieldsAndWidgets
    """
    meta_type = portal_type = archetype_name = 'BrFieldsAndWidgetsDemo'
    content_icon = "document_icon.gif"
    schema = schema
    security = ClassSecurityInfo()


atapi.registerType(BrFieldsAndWidgetsDemo, PROJECTNAME)



## Script (Python) "lstDDD"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=value='',part='complete'
##title=
##

value = str(value)
tmpReturn = ''

if not value:
    return tmpReturn
    
isSpecialPhone = value.startswith('0')

displayFmt = (isSpecialPhone and '%s%s%s') or '(%s)%s-%s'

tmpDDD = (isSpecialPhone and value[:4]) or value[:2]
tmpPhone = (isSpecialPhone and value[4:]) or value[2:]
tmpPhone1 = tmpPhone[:-4]
tmpPhone2 = tmpPhone[-4:]

if part == 'complete':
    tmpReturn = displayFmt % (tmpDDD,tmpPhone1,tmpPhone2)
elif part == 'ddd':
    tmpReturn = tmpDDD
else:
    tmpReturn = tmpPhone

return tmpReturn


from setuptools import setup, find_packages
import os

version = open(os.path.join("Products", "BrFieldsAndWidgets", 
                            "version.txt")).read().strip()

setup(name='Products.BrFieldsAndWidgets',
      version=version,
      description="Brazilian fields and widgets to be used with Plone and Archetypes",
      long_description=open(os.path.join("README.rst")).read() + '\n' +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      classifiers=[
        "Framework :: Plone",
        "Framework :: Plone :: 3.3",
        "Framework :: Plone :: 4.0",
        "Framework :: Plone :: 4.1",
        "Framework :: Zope2",
        "Framework :: Zope3",
        "Intended Audience :: Developers",
        "Natural Language :: Portuguese (Brazilian)",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='plone archetypes widget BrFieldsAndWidgets brazil brasil',
      author='Simples Consultoria',
      author_email='products@simplesconsultoria.com.br',
      url='https://github.com/collective/Products.BrFieldsAndWidgets',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['Products'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
          'collective.brasil.vocab>=0.8',
      ],
      extras_require={
        'test': ['plone.app.testing'],
        },
      entry_points="""
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )



# -*- coding: utf-8 -*-
import unittest2 as unittest

from plone.app.testing import TEST_USER_ID
from plone.app.testing import TEST_USER_NAME
from plone.app.testing import login
from plone.app.testing import setRoles

from Products.BrFieldsAndWidgets.testing import INTEGRATION_TESTING

PROJECTNAME = 'Products.BrFieldsAndWidgets'


class BaseTestCase(unittest.TestCase):
    """base test case to be used by other tests"""

    layer = INTEGRATION_TESTING

    def setUpUser(self):
        setRoles(self.portal, TEST_USER_ID, ['Manager', 'Editor', 'Reviewer'])
        login(self.portal, TEST_USER_NAME)

    def setUp(self):
        portal = self.layer['portal']
        self.portal = portal
        self.qi = getattr(self.portal, 'portal_quickinstaller')
        self.pp = getattr(self.portal, 'portal_properties')
        self.st = getattr(self.portal, 'portal_setup')
        self.skins = getattr(self.portal, 'portal_skins')
        self.setUpUser()


class TestInstall(BaseTestCase):
    """ensure product is properly installed"""

    def test_installed(self):
        PROJECTNAME = 'BrFieldsAndWidgets'
        self.failUnless(self.qi.isProductInstalled(PROJECTNAME),
                        '%s not installed' % PROJECTNAME)

    def test_skin_layer_installed(self):
        self.failUnless('BrF_images' in self.skins.objectIds())
        self.failUnless('BrF_templates' in self.skins.objectIds()) 


class TestUninstall(BaseTestCase):
    """ensure product is properly uninstalled"""

    def setUp(self):
        BaseTestCase.setUp(self)
        PROJECTNAME = 'BrFieldsAndWidgets'
        self.qi.uninstallProducts(products=[PROJECTNAME])

    def test_uninstalled(self):
        PROJECTNAME = 'BrFieldsAndWidgets'
        self.failIf(self.qi.isProductInstalled(PROJECTNAME))

    def test_skin_layer_uninstalled(self):
        self.failIf('BrF_images' in self.skins.objectIds())
        self.failIf('BrF_templates' in self.skins.objectIds()) 


def test_suite():
    return unittest.defaultTestLoader.loadTestsFromName(__name__)



# -*- coding: utf-8 -*-
__author__ = """Simples Consultoria <contato@simplesconsultoria.com.br>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes import atapi

from Products.BrFieldsAndWidgets.content.BrFieldsAndWidgets import CEPField
from Products.BrFieldsAndWidgets.content.BrFieldsAndWidgets import CEPWidget

from Products.BrFieldsAndWidgets import MessageFactory as _


schema = atapi.Schema((
    atapi.StringField(
        name='logradouro',
        widget=atapi.StringWidget(
            size="30",
            visible={'view': 'invisible', 'edit': 'visible'},
            label=_(u'Logradouro'),
            description=_(u'Exemplo: Rua Mourato Coelho'),
        ),
        required=True,
        schemata="Address"
    ),

    atapi.StringField(
        name='numero',
        widget=atapi.StringWidget(
            size="7",
            visible={'view': 'invisible', 'edit': 'visible'},
            label=_(u'Número'),
            description=_(u'Exemplo: 12'),
        ),
        required=True,
        schemata="Address"
    ),

    atapi.StringField(
        name='complemento',
        widget=atapi.StringWidget(
            visible={'view': 'invisible', 'edit': 'visible'},
            label=_(u'Complemento'),
        ),
        schemata="Address"
    ),

    atapi.StringField(
        name='bairro',
        widget=atapi.StringWidget(
            visible={'view': 'invisible', 'edit': 'visible'},
            size="30",
            label=_(u'Bairro'),
            description=_(u'Exemplo: Pinheiros'),
        ),
        required=False,
        schemata="Address",
    ),

    CEPField(
        name='cep',
        required=1,
        widget=CEPWidget(
                        visible={'view': 'invisible', 'edit': 'visible'},
                        label=_(u'CEP'),
                        description=_(u'Informe o CEP.'),
                        ),
        schemata="Address"
    ),

    atapi.StringField(
        name='cidade',
        widget=atapi.StringWidget(
            visible={'view': 'invisible', 'edit': 'visible'},
            label=_(u'Cidade'),
            description=_(u'Informe sua cidade.'),
        ),
        required=True,
        schemata="Address"
    ),

    atapi.StringField(
        name='uf',
        widget=atapi.SelectionWidget
        (
            visible={'view': 'invisible', 'edit': 'visible'},
            size=1,
            label=_(u'UF'),
            description=_(u'Informe o seu estado.'),
        ),
        required=True,
        schemata="Address",
        vocabulary_factory='brasil.estados',
        enforceVocabulary=True,
    ),

    atapi.ComputedField(
        name='Endereco',
        expression='context.fmt_endereco()',
        widget=atapi.ComputedWidget(
            visible={'view': 'visible', 'edit': 'invisible'},
            label=_(u'Endereço'),
        ),
        default_output_type='text/x-html-safe',
        schemata="Address",
        searchable=True
    ),

    atapi.TextField(
        name='referencia',
        allowable_content_types=('text/html', ),
        widget=atapi.RichWidget
        (
            visible={'view': 'invisible', 'edit': 'invisible'},
            label=_(u'Referência'),
            description=_(u'Informe pontos de referência.'),
        ),
        required=False,
        schemata="Address",
        searchable=True,
        default_output_type='text/x-html-safe'
    ),

),
)


br_endereco_schema = atapi.BaseSchema.copy() + schema.copy()


class br_endereco:
    """Classe basica de endereco
    """
    security = ClassSecurityInfo()

    # This name appears in the 'add' box
    archetype_name = 'br_endereco'

    meta_type = 'br_endereco'
    portal_type = 'br_endereco'
    allowed_content_types = []
    filter_content_types = 0
    global_allow = 0
    #content_icon = 'br_endereco.gif'
    immediate_view = 'base_view'
    default_view = 'base_view'
    suppl_views = ()
    typeDescription = "br_endereco"
    typeDescMsgId = 'description_edit_br_endereco'

    _at_rename_after_creation = True

    schema = br_endereco_schema

    security.declarePrivate('fmt_endereco')

    def fmt_endereco(self):
        """Retorna um endereco formatado para o atributo Endereco
        """
        template = "%s,%s %s<br/>%s<br/>%s<br/>%s - %s"
        logradouro = self.getLogradouro()
        numero = self.getNumero()
        complemento = self.getComplemento()
        bairro = self.getBairro()
        cep = self.getCep()
        if cep:
            cep = "%s-%s" % (cep[:5], cep[-3:])
        cidade = self.getCidade()
        uf= self.getUf()

        return template % (logradouro,
                           numero,
                           complemento,
                           bairro,
                           cep,
                           cidade,
                           uf)



## Script (Python) "lstDDD"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=obj=None
##title=
##

lstCodArea = [11, # Grande Sao Paulo
          12, 
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          21,
          22, # Interior do RJ
          24,
          27,
          28, # Interior do ES
          31,
          32,
          33,
          34,
          35,
          37,
          38,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          51,
          53,
          54,
          55,
          61,
          62,
          63,
          64, # Interior de GO
          65,
          66, # Interior do MT
          67,
          68,
          69,
          71,
          73,
          74,
          75,
          77,
          79,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89, # Interior do PI
          91,
          92,
          93, # Interior do PA
          94, # Interior do PA
          95,
          96,
          97, # Interior do AM
          98,
          99, # Interior do MA
          '0300',
          '0500',
          '0800',]
         
lstTupCodArea = [(item, item) for item in lstCodArea]     
lstReturn = [('','--')]

return lstReturn + lstTupCodArea